@@ -7,25 +7,6 @@ from hachoir_core.tools import makePrintable, timedelta2seconds, humanBitRate
 from datetime import timedelta, date
 from hachoir_metadata.metadata_item import QUALITY_FAST, QUALITY_NORMAL, QUALITY_BEST
 from hachoir_metadata.safe import fault_tolerant, getValue
-from hachoir_metadata.formatter import setLanguage
-
-def setTrackTotal(meta, key, total):
-    try:
-        meta.track_total = int(total)
-    except ValueError:
-        meta.warning("Invalid track total: %r" % total)
-
-def setTrackNumber(meta, key, number):
-    if isinstance(number, (int, long)):
-        meta.track_number = number
-        return
-    if "/" in number:
-        number, total = number.split("/", 1)
-        setTrackTotal(meta, "track_total", total)
-    try:
-        meta.track_number = int(number)
-    except ValueError:
-        meta.warning("Invalid track number: %r" % number)
 
 def computeComprRate(meta, size):
     if not meta.has("duration") \
@@ -46,22 +27,23 @@ def computeBitRate(meta):
 
 class OggMetadata(MultipleMetadata):
     KEY_TO_ATTR = {
-        "ARTIST": ("artist", None),
-        "ALBUM": ("album", None),
-        "TRACKNUMBER": ("track_number", setTrackNumber),
-        "TRACKTOTAL": ("track_total", setTrackTotal),
-        "ENCODER": ("producer", None),
-        "TITLE": ("title", None),
-        "DATE": ("creation_date", None),
-        "ORGANIZATION": ("organization", None),
-        "GENRE": ("music_genre", None),
-        "": ("comment", None),
-        "COMPOSER": ("music_composer", None),
-        "DESCRIPTION": ("comment", None),
-        "COMMENT": ("comment", None),
-        "WWW": ("url", None),
-        "WOAF": ("url", None),
-        "LICENSE": ("copyright", None),
+        "ARTIST": "artist",
+        "ALBUM": "album",
+        "TRACKNUMBER": "track_number",
+        "TRACKTOTAL": "track_total",
+        "ENCODER": "producer",
+        "TITLE": "title",
+        "LOCATION": "location",
+        "DATE": "creation_date",
+        "ORGANIZATION": "organization",
+        "GENRE": "music_genre",
+        "": "comment",
+        "COMPOSER": "music_composer",
+        "DESCRIPTION": "comment",
+        "COMMENT": "comment",
+        "WWW": "url",
+        "WOAF": "url",
+        "LICENSE": "copyright",
     }
 
     def extract(self, ogg):
@@ -138,11 +120,8 @@ class OggMetadata(MultipleMetadata):
                 key, value = metadata.value.split("=", 1)
                 key = key.upper()
                 if key in self.KEY_TO_ATTR:
-                    key, setter = self.KEY_TO_ATTR[key]
-                    if setter:
-                        setter(self, key, value)
-                    else:
-                        setattr(self, key, value)
+                    key = self.KEY_TO_ATTR[key]
+                    setattr(self, key, value)
                 elif value:
                     self.warning("Skip Ogg comment %s: %s" % (key, value))
 
@@ -155,11 +134,10 @@ class AuMetadata(RootMetadata):
             self.comment = audio["info"].value
         self.bits_per_sample = audio.getBitsPerSample()
         computeBitRate(self)
-        if "audio_data" in audio \
-        and self.has("bit_rate"):
-            self.duration = timedelta(seconds=float(audio["audio_data"].size) / self.get('bit_rate'))
-        if "data_size" in audio:
-            computeComprRate(self, audio["data_size"].value*8)
+        if "audio_data" in audio:
+            if self.has("bit_rate"):
+                self.duration = timedelta(seconds=float(audio["audio_data"].size) / self.get('bit_rate'))
+            computeComprRate(self, audio["audio_data"].size)
 
 class RealAudioMetadata(RootMetadata):
     FOURCC_TO_BITRATE = {
@@ -265,26 +243,31 @@ class RealMediaMetadata(MultipleMetadata):
 class MpegAudioMetadata(RootMetadata):
     TAG_TO_KEY = {
         # ID3 version 2.2
-        "TP1": ("author", None),
-        "COM": ("comment", None),
-        "TEN": ("producer", None),
-        "TRK": ("track_number", setTrackNumber),
-        "TAL": ("album", None),
-        "TT2": ("title", None),
-        "TYE": ("creation_date", None),
-        "TCO": ("music_genre", None),
+        "TP1": "author",
+        "COM": "comment",
+        "TEN": "producer",
+        "TRK": "track_number",
+        "TAL": "album",
+        "TT2": "title",
+        "TYE": "creation_date",
+        "TCO": "music_genre",
 
         # ID3 version 2.3+
-        "TPE1": ("author", None),
-        "COMM": ("comment", None),
-        "TENC": ("producer", None),
-        "TRCK": ("track_number", setTrackNumber),
-        "TALB": ("album", None),
-        "TIT2": ("title", None),
-        "TYER": ("creation_date", None),
-        "WXXX": ("url", None),
-        "TCON": ("music_genre", None),
-        "TLAN": ("language", setLanguage),
+        "TPE1": "author",
+        "COMM": "comment",
+        "TENC": "producer",
+        "TRCK": "track_number",
+        "TALB": "album",
+        "TIT2": "title",
+        "TYER": "creation_date",
+        "WXXX": "url",
+        "TCON": "music_genre",
+        "TLAN": "language",
+        "TCOP": "copyright",
+        "TDAT": "creation_date",
+        "TRDA": "creation_date",
+        "TORY": "creation_date",
+        "TIT1": "title",
     }
 
     def processID3v2(self, field):
@@ -307,11 +290,8 @@ class MpegAudioMetadata(RootMetadata):
                     tag = makePrintable(tag, "ISO-8859-1", to_unicode=True)
                 self.warning("Skip ID3v2 tag %s: %s" % (tag, value))
             return
-        key, setter = self.TAG_TO_KEY[tag]
-        if setter:
-            setter(self, key, value)
-        else:
-            setattr(self, key, value)
+        key = self.TAG_TO_KEY[tag]
+        setattr(self, key, value)
 
     def readID3v2(self, id3):
         for field in id3:
@@ -339,7 +319,7 @@ class MpegAudioMetadata(RootMetadata):
             if id3["year"].value != "0":
                 self.creation_date = id3["year"].value
             if "track_nb" in id3:
-                setTrackNumber(self, "track_number", id3["track_nb"].value)
+                self.track_number = id3["track_nb"].value
         if "id3v2" in mp3:
             self.readID3v2(mp3["id3v2"])
         if "frames" in mp3:
