@@ -13,7 +13,6 @@ from hachoir_core.tools import (makeUnicode, makePrintable,
     durationWin64, timedelta2seconds)
 from hachoir_core.error import warning
 from datetime import timedelta
-from hachoir_metadata.formatter import setLanguage
 
 class MkvMetadata(MultipleMetadata):
     tag_key = {
@@ -65,7 +64,7 @@ class MkvMetadata(MultipleMetadata):
             meta.title = track["Name/unicode"].value
         if "Language/string" in track \
         and track["Language/string"].value not in ("mis", "und"):
-            setLanguage(meta, "language", track["Language/string"].value)
+            meta.language = track["Language/string"].value
 
     def processVideo(self, track):
         video = Metadata(self)
@@ -140,14 +139,14 @@ class MkvMetadata(MultipleMetadata):
 
 class FlvMetadata(MultipleMetadata):
     def extract(self, flv):
-        if "audio[0]" in flv:
-            meta = Metadata(self)
-            self.extractAudio(flv["audio[0]"], meta)
-            self.addGroup("audio", meta)
         if "video[0]" in flv:
             meta = Metadata(self)
             self.extractVideo(flv["video[0]"], meta)
-            self.addGroup("video", meta)
+            self.addGroup("video", meta, "Video stream")
+        if "audio[0]" in flv:
+            meta = Metadata(self)
+            self.extractAudio(flv["audio[0]"], meta)
+            self.addGroup("audio", meta, "Audio stream")
         # TODO: Computer duration
         # One technic: use last video/audio chunk and use timestamp
         # But this is very slow
@@ -210,30 +209,48 @@ class MovMetadata(RootMetadata):
 
     @fault_tolerant
     def processMovieHeader(self, hdr):
-        self.creation_date = hdr["creat_date"].value
+        self.creation_date = hdr["creation_date"].value
         self.last_modification = hdr["lastmod_date"].value
         self.duration = timedelta(seconds=float(hdr["duration"].value) / hdr["time_scale"].value)
         self.comment = _("Play speed: %.1f%%") % (hdr["play_speed"].value*100)
         self.comment = _("User volume: %.1f%%") % (float(hdr["volume"].value)*100//255)
 
+    @fault_tolerant
+    def processTrackHeader(self, hdr):
+        width = int(hdr["frame_size_width"].value)
+        height = int(hdr["frame_size_height"].value)
+        if width and height:
+            self.width = width
+            self.height = height
+
+    def processTrack(self, atom):
+        for field in atom:
+            if "track_hdr" in field:
+                self.processTrackHeader(field["track_hdr"])
+
     def processMovie(self, atom):
         for field in atom:
+            if "track" in field:
+                self.processTrack(field["track"])
             if "movie_hdr" in field:
                 self.processMovieHeader(field["movie_hdr"])
 
+
 class AsfMetadata(MultipleMetadata):
     EXT_DESC_TO_ATTR = {
         "Encoder": "producer",
         "ToolName": "producer",
         "AlbumTitle": "album",
         "Track": "track_number",
-        "TrackNumber": "track_number",
+        "TrackNumber": "track_total",
         "Year": "creation_date",
+        "AlbumArtist": "author",
     }
     SKIP_EXT_DESC = set((
         # Useless informations
         "WMFSDKNeeded", "WMFSDKVersion",
-        "Buffer Average", "VBR Peak",
+        "Buffer Average", "VBR Peak", "EncodingTime",
+        "MediaPrimaryClassID", "UniqueFileIdentifier",
     ))
 
     def extract(self, asf):
@@ -333,6 +350,9 @@ class AsfMetadata(MultipleMetadata):
             # Skip binary data
             return
         key = desc["name"].value
+        if "/" in key:
+            # Replace "WM/ToolName" with "ToolName"
+            key = key.split("/", 1)[1]
         if key in self.SKIP_EXT_DESC:
             # Skip some keys
             return
@@ -340,9 +360,6 @@ class AsfMetadata(MultipleMetadata):
         if not value:
             return
         value = makeUnicode(value)
-        if "/" in key:
-            # Replace "WM/ToolName" with "ToolName"
-            key = key.split("/", 1)[1]
         data[key] = value
 
     @fault_tolerant
