@@ -17,6 +17,7 @@ from hachoir_parser import createParser
 from hachoir_core.compatibility import all
 from hachoir_core.language import Language
 from hachoir_metadata import extractMetadata
+from hachoir_metadata.timezone import createTimezone
 from datetime import date, timedelta, datetime
 from locale import setlocale, LC_ALL
 import os
@@ -296,6 +297,49 @@ def checkDebianTorrent(meta): return (
     checkAttr(meta, "creation_date", datetime(2006, 11, 16, 21, 44, 37)),
 )
 
+def checkGreenFire(meta): return (
+    checkAttr(meta, 'height', 64),
+    checkAttr(meta, 'bits_per_pixel', 32),
+    checkAttr(meta, 'comment', (u"Intel(R) JPEG Library, version 1,5,4,36", u"JPEG quality: 80%")),
+)
+
+def checkMarcKravetz(meta): return (
+    checkAttr(meta, 'creation_date', datetime(2007, 7, 19, 9, 3, 57, tzinfo=createTimezone(2))),
+    checkAttr(meta, 'sample_rate', 48000),
+    checkAttr(meta, 'compr_rate', 12.0),
+    checkAttr(meta, 'album', u"France Culture - Le portrait du jour par Marc Kravetz"),
+    checkAttr(meta, 'author', u"Marc Kravetz"),
+    checkAttr(meta, 'duration', timedelta(0, 2, 400000)),
+    checkAttr(meta, 'bit_rate', 128000),
+    checkAttr(meta, 'track_number', 32),
+    checkAttr(meta, 'bits_per_sample', 16),
+    checkAttr(meta, 'copyright', u"Radio France"),
+    checkAttr(meta, 'format_version', u"MPEG version 1 layer III"),
+)
+
+def checkPentax320(meta): return (
+    checkAttr(meta, 'width', 320),
+    checkAttr(meta, 'height', 240),
+    checkAttr(meta, 'duration', timedelta(0, 4, 966667)),
+    checkAttr(meta, 'creation_date', datetime(2005, 8, 11, 14, 3, 54)),
+    checkAttr(meta, 'last_modification', datetime(2005, 8, 11, 14, 3, 54)),
+)
+
+def checkGPS(meta): return (
+    checkAttr(meta, 'altitude', 78.0),
+    checkAttr(meta, 'creation_date', datetime(2003, 5, 24, 22, 29, 14)),
+    checkAttr(meta, 'latitude', 35.616019444444447),
+    checkAttr(meta, 'longitude', 139.69731666666667),
+    checkAttr(meta, 'camera_model', u'A5301T'),
+    checkAttr(meta, 'camera_manufacturer', u'KDDI-TS'),
+)
+
+def checkAngelBear(meta): return (
+    checkAttr(meta, 'title', u"Angel Bear"),
+    checkAttr(meta, 'artist', u"Copyright ©Loraine Wauer-Ferus http://www.billybear4kids.com"),
+    checkAttr(meta, 'frame_rate', 4.0),
+)
+
 def checkFile(filename, check_metadata, quality=1.0):
     sys.stdout.write("  - Create parser: ")
     sys.stdout.flush()
@@ -398,6 +442,11 @@ testcase_files = (
     (u"deja_vu_serif-2.7.ttf", checkDejaVu),
     (u"twunk_16.exe", checkTwunk16),
     (u"debian-31r4-i386-binary-1.iso.torrent", checkDebianTorrent),
+    (u"green_fire.jpg", checkGreenFire),
+    (u"marc_kravetz.mp3", checkMarcKravetz),
+    (u"pentax_320x240.mov", checkPentax320),
+    (u"gps.jpg", checkGPS),
+    (u"angle-bear-48x48.ani", checkAngelBear),
 )
 
 if __name__ == "__main__":
